@@ -177,6 +177,7 @@ public:
 		static const char *chkClear(script *img, script::header *scr, script::line_t *line);
 		static const char *chkError(script *img, script::header *scr, script::line_t *line);
 		static const char *chkPack(script *img, script::header *scr, script::line_t *line);
+		static const char *chkExpand(script *img, script::header *scr, script::line_t *line);
 		static const char *chkGosub(script *img, script::header *src, script::line_t *line);
 		static const char *chkGoto(script *img, script::header *scr, script::line_t *line);
 		static const char *chkDo(script *img, script::header *scr, script::line_t *line);
@@ -188,7 +189,6 @@ public:
 		static const char *chkLoop(script *img, script::header *scr, script::line_t *line);
 		static const char *chkPrevious(script *img, script::header *scr, script::line_t *line);
 		static const char *chkIndex(script *img, script::header *scr, script::line_t *line);
-		static const char *chkFor(script *img, script::header *scr, script::line_t *line);
 		static const char *chkForeach(script *img, script::header *scr, script::line_t *line);
 		static const char *chkCase(script *img, script::header *scr, script::line_t *line);
 		static const char *chkEndcase(script *img, script::header *scr, script::line_t *line);
@@ -402,6 +402,7 @@ public:
 		bool scrPause(void);
 		bool scrNop(void);
 		bool scrPack(void);
+		bool scrExpand(void);
 		bool scrExit(void);
 		bool scrReturn(void);
 		bool scrError(void);
@@ -414,7 +415,6 @@ public:
 		bool scrWhile(void);
 		bool scrBreak(void);
 		bool scrContinue(void);
-		bool scrFor(void);
 		bool scrForeach(void);
 		bool scrPrevious(void);
 		bool scrRepeat(void);
