@@ -161,9 +161,6 @@ const char *script::checks::chkPrevious(script *img, script::header *scr, script
 	if(method == (method_t)NULL)
 		return "cannot be called outside loop";
 
-	if(method == (method_t)&script::methods::scrFor)
-		goto valid;
-
 	if(method == (method_t)&script::methods::scrForeach)
 		goto valid;
 
@@ -186,9 +183,6 @@ const char *script::checks::chkContinue(script *img, script::header *scr, script
 	if(method == (method_t)&script::methods::scrDo)
 		goto valid;
 
-	if(method == (method_t)&script::methods::scrFor)
-		goto valid;
-
 	if(method == (method_t)&script::methods::scrWhile)
 		goto valid;
 
@@ -270,6 +264,41 @@ const char *script::checks::chkWhile(script *img, script::header *scr, script::l
 	return chkConditional(img, scr, line);
 }
 
+const char *script::checks::chkExpand(script *img, script::header *scr, script::line_t *line)
+{
+	unsigned index = 1;
+	const char *cp;
+
+	if(line->argc < 1)
+		return "no value to expand";
+
+	if(line->argc < 2)
+		return "no symbols to assign";
+
+	if(!isValue(line->argv[0]))
+		return "cannot expand non-value";
+
+	while(line->argv[index]) {
+		cp = line->argv[0];
+		switch(*cp) {
+		case '&':
+			return "cannot assign literal";
+		case '=':
+			return "no keywords are used in this command";
+		case '$':
+			return "cannot assign fielded symbols";
+		case '@':
+			return "cannot assign to label";
+		case '^':
+			return "cannot assign to event";
+		case '?':
+			return "cannot assign to expression";
+		}		
+		strict::createAny(img, scr, line->argv[index++]);
+	}
+	return NULL;
+}
+
 const char *script::checks::chkForeach(script *img, script::header *scr, script::line_t *line)
 {
 	const char *cp;
@@ -312,51 +341,6 @@ const char *script::checks::chkForeach(script *img, script::header *scr, script:
 	return NULL;
 }
 
-const char *script::checks::chkFor(script *img, script::header *scr, script::line_t *line)
-{
-	unsigned index = 1;
-	const char *cp;
-
-	if(String::equal(scr->name, "_init_"))
-		return "this command cannot be used to initialize";
-
-	if(!img->push(line))
-		return "stack overflow for do command";
-
-	if(!line->argc)
-		return "no symbols to assign";
-
-	if(line->argc < 2)
-		return "no values to assign";
-
-	cp = line->argv[0];
-	switch(*cp) {
-	case '&':
-		return "cannot assign literal";
-	case '=':
-		return "no keywords are used in this command";
-	case '$':
-		return "cannot assign fielded symbols";
-	case '@':
-		return "cannot assign to label";
-	case '^':
-		return "cannot assign to event";
-	case '?':
-		return "cannot assign to expression";
-	}		
-	
-	strict::createAny(img, scr, line->argv[0]);
-
-	while(index < line->argc) {
-		cp = line->argv[index++];
-		if(*cp == '=')
-			return "no keywords are used in this command";
-		if(!isValue(cp))
-			return "cannot assign from label or expression";
-	}
-	return NULL;
-}
-
 const char *script::checks::chkDo(script *img, script::header *scr, script::line_t *line)
 {
 	if(String::equal(scr->name, "_init_"))
@@ -414,9 +398,6 @@ const char *script::checks::chkLoop(script *img, script::header *scr, script::li
 	if(method == (method_t)&script::methods::scrDo)
 		goto valid;
 
-	if(method == (method_t)&script::methods::scrFor)
-		goto valid;
-
 	if(method == (method_t)&script::methods::scrForeach)
 		goto valid;
 
@@ -885,7 +866,8 @@ const char *script::checks::chkConditional(script *img, script::header *scr, scr
 				return "missing operator in expression";
 
 			cp = line->argv[index++];
-			if(*cp != '?')
+
+			if(*cp != '?' && !String::equal(cp, "eq") && !String::equal(cp, "ne") && !String::equal(cp, "lt") && !String::equal(cp, "gt") && !String::equal(cp, "le") && !String::equal(cp, "ge"))
 				return "invalid operator in expression";
 
 			if(index >= line->argc)
@@ -916,9 +898,6 @@ const char *script::checks::chkIndex(script *img, script::header *scr, script::l
 	if(method == (method_t)NULL)
 		return "cannot be called outside loop";
 
-	if(method == (method_t)&script::methods::scrFor)
-		goto valid;
-
 	if(method == (method_t)&script::methods::scrForeach)
 		goto valid;
 
