@@ -334,6 +334,7 @@ void script::init(void)
 		{"set", (method_t)&methods::scrSet, (check_t)&checks::chkSet},
 		{"add", (method_t)&methods::scrAdd, (check_t)&checks::chkSet},
 		{"pack", (method_t)&methods::scrPack, (check_t)&checks::chkPack},
+		{"expand", (method_t)&methods::scrExpand, (check_t)&checks::chkExpand},
 		{"do", (method_t)&methods::scrDo, (check_t)&checks::chkDo},
 		{"until", (method_t)&methods::scrUntil, (check_t)&checks::chkUntil},
 		{"break", (method_t)&methods::scrBreak, (check_t)&checks::chkBreak},
@@ -343,7 +344,7 @@ void script::init(void)
 		{"index", (method_t)&methods::scrIndex, (check_t)&checks::chkIndex},
 		{"loop", (method_t)&methods::scrLoop, (check_t)&checks::chkLoop},
 		{"while", (method_t)&methods::scrWhile, (check_t)&checks::chkWhile},
-		{"for", (method_t)&methods::scrFor, (check_t)&checks::chkFor},
+		{"for", (method_t)&methods::scrForeach, (check_t)&checks::chkForeach},
 		{"foreach", (method_t)&methods::scrForeach, (check_t)&checks::chkForeach},
 		{"case", (method_t)&methods::scrCase, (check_t)&checks::chkCase},
 		{"otherwise", (method_t)&methods::scrOtherwise, (check_t)&checks::chkOtherwise},
@@ -977,18 +978,23 @@ unsigned script::count(const char *data)
 {
 	unsigned count = 0;
 	char quote = 0;
+	unsigned paren = 0;
 
 	if(!data || !*data)
 		return 0;
 
 	++count;
 	while(*data) {
-		if(*data == ',' && !quote)
+		if(*data == ',' && !quote && !paren)
 			++count;
-		else if(*data == quote)
+		else if(*data == quote && !paren)
 			quote = 0;
-		else if(*data == '\"')
+		else if(*data == '\"' && !paren)
 			quote = *data;
+		else if(*data == '(' && !quote)
+			++paren;
+		else if(*data == ')' && !quote)
+			--paren;
 		++data;
 	}
 	return count;		
@@ -1002,19 +1008,37 @@ void script::copy(const char *list, char *item, unsigned size)
 	bool lead = false;
 	char quote = 0;
 	char prev = 0;
+	unsigned paren = 0;
+	bool leadparen = false;
 	
 	if(!list || !*list || *list == ',') {
 		*item = 0;
 		return;
 	}
 
-	if(*list == '\"') {
-		quote = *(list++);
-		lead = true;
+	while(isspace(*list))
+		++list;
+
+	if(*list == '(') {
+		leadparen = true;
+		++paren;
+		++list;
+	}
+	else {
+		if(*list == '\"' || *list == '\'') {
+			quote = *(list++);
+			lead = true;
+		}
 	}
 
 	while(--size && *list) {
-		if(*list == ',' && !quote)
+		if(paren == 1 && leadparen && *list == ')' && !quote)
+			break;
+		if(*list == '(')
+			++paren;
+		else if(*list == ')')
+			--paren;
+		if(*list == ',' && !quote && !paren)
 			break;
 		if(*list == quote && lead)
 			break;
@@ -1022,7 +1046,7 @@ void script::copy(const char *list, char *item, unsigned size)
 			*(item++) = quote;
 			break;
 		}
-		if(!quote && *list == '\"' && prev == '=')
+		if(!quote && *list == '\"' && prev == '=' && !paren)
 			quote = *list;
 		prev = *item;
 		*(item++) = *(list++);
@@ -1039,6 +1063,7 @@ unsigned script::offset(const char *list, unsigned index)
 const char *script::get(const char *list, unsigned index)
 {
 	char quote = 0;
+	unsigned paren = 0;
 
 	if(!list || !*list)
 		return NULL;
@@ -1047,13 +1072,17 @@ const char *script::get(const char *list, unsigned index)
 		return list;
 
 	while(*list && index) {	
-		if(*list == ',' && !quote) {
+		if(*list == ',' && !quote && !paren) {
 			--index;
 			if(!index) 
 				return ++list;
 		} else if(*list == quote)
 			quote = 0;
-		else if(*list == '\"')
+		else if(*list == '(' && !quote)
+			++paren;
+		else if(*list == ')' && !quote)
+			--paren;
+		else if(*list == '\"' && !paren)
 			quote = *list;
 		++list;
 	}
