@@ -121,10 +121,14 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	char quote = 0;
 	script::symbol *index = NULL;
 
+	cp = sym->data;
+	while(isspace(*cp))
+		++cp;
+
 	if(String::equal(id, "len:", 4)) 
 		snprintf(tp, script::sizing + 1, "%u", (unsigned)strlen(sym->data));
 	else if(String::equal(id, "key:", 4)) {
-		String::set(tp, script::sizing + 1, sym->data);
+		String::set(tp, script::sizing + 1, cp);
 		ep = strchr(tp, '=');
 		if(ep)
 			*ep = 0; 
@@ -134,7 +138,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	else if(String::equal(id, "tail:", 5)) {
 		dcount = script::count(sym->data);
 		if(dcount)
-			String::set(tp, script::sizing + 1, script::get(sym->data, --dcount));
+			String::set(tp, script::sizing + 1, script::get(cp, --dcount));
 		else
 			tp[0] = 0;
 	}
@@ -170,9 +174,12 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		else
 			tp[0] = 0;
 	}		
-	else if(String::equal(id, "val:", 4) && (sym->data[0] == '\'' || sym->data[0] == '\"')) {
-		String::set(tp, script::sizing + 1, sym->data + 1);
-		ep = strchr(tp, sym->data[0]);
+	else if(String::equal(id, "val:", 4) && (*cp == '\'' || *cp == '\"' || *cp == '(')) {
+		String::set(tp, script::sizing + 1, cp + 1);
+		if(*cp == '(')
+			ep = strrchr(tp, ')');
+		else
+			ep = strchr(tp, *cp);
 		if(ep)
 			*ep = 0;
 	}
@@ -191,8 +198,35 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 				*ep = 0;
 		}
 	}  
+	else if(String::equal(id, "unquote:", 8) && sym->size) {
+		cp = sym->data;
+		while(isspace(*cp))
+			++cp;
+		if(*cp == '(') {
+			++cp;
+			ep = strrchr(cp, ')');
+			if(ep)
+				*ep = 0;
+		}
+		else if(*cp == '\"' || *cp == '\'') {
+			ep = strchr(cp + 1, *cp); 
+			if(ep)
+				*ep = 0;
+			++cp;
+		}
+		String::set(sym->data, sym->size + 1, cp);
+		return sym->data;
+	}
+	else if(String::equal(id, "upper:", 6) && sym->size) {
+		String::upper(sym->data);
+		return sym->data;
+	}
+	else if(String::equal(id, "lower:", 6) && sym->size) {
+		String::lower(sym->data);
+		return sym->data;
+	}	
 	else if(String::equal(id, "inc:", 4) && sym->size) {
-		val = atol(sym->data);
+		val = atol(cp);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, ++val);
 		return sym->data;
 	}
@@ -240,18 +274,18 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		script::copy(cp, tp, script::sizing);
 	}
 	else if(String::equal(id, "dec:", 4) && sym->size) {
-		val = atoi(sym->data);
+		val = atoi(cp);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, --val);
 		return sym->data;
 	}
 	else if(String::equal(id, "size:", 5))
 		snprintf(tp, script::sizing + 1, "%d", sym->size);
 	else if(String::equal(id, "val:", 4) || !strnicmp(id, "int:", 4)) {
-		val = atol(sym->data);
+		val = atol(cp);
 		snprintf(tp, script::sizing + 1, NUM_FORMAT, val);
 	}
 	else if(String::equal(id, "num:", 4)) {
-		val = atol(sym->data);
+		val = atol(cp);
 		snprintf(tp, script::sizing + 1, NUM_FORMAT, val);
 		if(script::decimals)
 			String::add(tp, script::sizing + 1, ".");
@@ -401,7 +435,7 @@ const char *script::interp::getIndex(void)
 	unsigned pos = frame;
 	while(pos) {
 		method = stack[--pos].line->method;
-		if(method == (method_t)&script::methods::scrFor || method == (method_t)&script::methods::scrForeach) {
+		if(method == (method_t)&script::methods::scrForeach) {
 			char *temp = getTemp();
 			snprintf(temp, script::sizing, "%d", stack[pos].index);
 			return temp;
@@ -1180,9 +1214,7 @@ bool script::interp::getExpression(unsigned index)
 
 	if(index <= line->argc) {
 		op = line->argv[index++];
-		if(*op != '?')
-			return false;
-		else
+		if(*op == '?')
 			++op;
 	}
 	else if(v1 && *v1)
@@ -1227,10 +1259,34 @@ bool script::interp::getExpression(unsigned index)
 	if(String::equal(op, "||"))
 		return (*v1 || *v2);
 
-	if(String::equal(op, "=="))
+	if(String::equal(op, "gt")) {
+		if(strcmp(v1, v2) > 0)
+			return true;
+		return false;
+	}
+
+	if(String::equal(op, "lt")) {
+		if(strcmp(v1, v2) < 0)
+			return true;
+		return false;
+	}
+
+	if(String::equal(op, "ge")) {
+		if(strcmp(v1, v2) >= 0)
+			return true;
+		return false;
+	}
+
+	if(String::equal(op, "le")) {
+		if(strcmp(v1, v2) <= 0)
+			return true;
+		return false;
+	}
+
+	if(String::equal(op, "==") || String::equal(op, "eq"))
 		return String::equal(v1, v2);
 
-	if(String::equal(op, "!="))
+	if(String::equal(op, "!=") || String::equal(op, "ne"))
 		return !String::equal(v1, v2);
 
 	if(String::equal(op, "<")) {
