@@ -28,6 +28,7 @@ static unsigned debugcount = 0;
 static unsigned printcount = 0;
 static unsigned eventchecks = 0;
 static unsigned loopingchecks = 0;
+static unsigned manipchecks = 0;
 
 class debug
 {
@@ -50,6 +51,7 @@ public:
 	bool scrCheckRefs(void);
 	bool scrArgs(void);
 	bool scrSleep(void);
+	bool scrCheckManip(void);
 };
 
 debug::debug()
@@ -66,6 +68,13 @@ void debug::print(void)
 		++printcount;
 }
 
+bool testing::scrCheckManip(void)
+{
+	++manipchecks;
+	skip();
+	return true;
+}
+
 bool testing::scrCheckEvent(void)
 {
 	++eventchecks;
@@ -145,6 +154,7 @@ int main(int argc, char **argv)
 		{"check.event", (script::method_t)&testing::scrCheckEvent, &script::checks::chkNop},
 		{"check.loop", (script::method_t)&testing::scrCheckLoop, &script::checks::chkNop},
 		{"check.refs", (script::method_t)&testing::scrCheckRefs, &script::checks::chkNop},
+		{"check.manip", (script::method_t)&testing::scrCheckManip, &script::checks::chkNop},
 		{"ignore", (script::method_t)&script::methods::scrNop, &script::checks::chkIgnore}, 
 		{"args", (script::method_t)&testing::scrArgs, &script::checks::chkIgnore},
 		{"sleep", (script::method_t)&testing::scrSleep, &script::checks::chkNop},
@@ -217,6 +227,9 @@ int main(int argc, char **argv)
 
 		// in  multiple inheritence, method call this* has combined class
 		assert(printcount == 1);
+
+		// check manipulations
+		assert(manipchecks == 8);
 	}
 
 	exit(0);
